#[repr(u8)]pub enum NetworkFault {
Unspecified = 0,
Hardwarefailure = 1,
Networkjammed = 2,
Connectionfailed = 3,
}Variants
Unspecified = 0
The Node has encountered an unspecified fault.
Hardwarefailure = 1
The Node has encountered a network fault as a result of a hardware failure.
Networkjammed = 2
The Node has encountered a network fault as a result of a jammed network.
Connectionfailed = 3
The Node has encountered a network fault as a result of a failure to establish a connection.
Implementations