#[repr(u8)]pub enum RadioFault {
Unspecified = 0,
Wififault = 1,
Cellularfault = 2,
Threadfault = 3,
Nfcfault = 4,
Blefault = 5,
Ethernetfault = 6,
}Variants
Unspecified = 0
The Node has encountered an unspecified radio fault.
Wififault = 1
The Node has encountered a fault with its Wi-Fi radio.
Cellularfault = 2
The Node has encountered a fault with its cellular radio.
Threadfault = 3
The Node has encountered a fault with its 802.15.4 radio.
Nfcfault = 4
The Node has encountered a fault with its NFC radio.
Blefault = 5
The Node has encountered a fault with its BLE radio.
Ethernetfault = 6
The Node has encountered a fault with its Ethernet controller.
Implementations