#[repr(u8)]pub enum BootReason {
Unspecified = 0,
Poweronreboot = 1,
Brownoutreset = 2,
Softwarewatchdogreset = 3,
Hardwarewatchdogreset = 4,
Softwareupdatecompleted = 5,
Softwarereset = 6,
}Variants
Unspecified = 0
The Node is unable to identify the Power-On reason as one of the other provided enumeration values.
Poweronreboot = 1
The Node has booted as the result of physical interaction with the device resulting in a reboot.
Brownoutreset = 2
The Node has rebooted as the result of a brown-out of the Node’s power supply.
Softwarewatchdogreset = 3
The Node has rebooted as the result of a software watchdog timer.
Hardwarewatchdogreset = 4
The Node has rebooted as the result of a hardware watchdog timer.
Softwareupdatecompleted = 5
The Node has rebooted as the result of a completed software update.
Softwarereset = 6
The Node has rebooted as the result of a software initiated reboot.
Implementations