#[repr(u8)]pub enum HardwareFault {
Unspecified = 0,
Radio = 1,
Sensor = 2,
Resettableovertemp = 3,
Nonresettableovertemp = 4,
Powersource = 5,
Visualdisplayfault = 6,
Audiooutputfault = 7,
Userinterfacefault = 8,
Nonvolatilememoryerror = 9,
Tamperdetected = 10,
}Variants
Unspecified = 0
The Node has encountered an unspecified fault.
Radio = 1
The Node has encountered a fault with at least one of its radios.
Sensor = 2
The Node has encountered a fault with at least one of its sensors.
Resettableovertemp = 3
The Node has encountered an over-temperature fault that is resettable.
Nonresettableovertemp = 4
The Node has encountered an over-temperature fault that is not resettable.
Powersource = 5
The Node has encountered a fault with at least one of its power sources.
Visualdisplayfault = 6
The Node has encountered a fault with at least one of its visual displays.
Audiooutputfault = 7
The Node has encountered a fault with at least one of its audio outputs.
Userinterfacefault = 8
The Node has encountered a fault with at least one of its user interfaces.
Nonvolatilememoryerror = 9
The Node has encountered a fault with its non-volatile memory.
Tamperdetected = 10
The Node has encountered disallowed physical tampering.
Implementations